************** GENERAL FUNCTION **********************
* POSTDP.prg
*
* USAGE;
*          POSTDP(<c-var>)
*
* RETURNS;
*          character variable, last 2 digits of
*          11 digit DPBC (Delivery Point Bar Code)
*          after interpeting street or BOX address
*          line contained in "c-var" above
* 
* !!!!!->> This code assumes that the street line
* !!!!!->> passed to function meets
* !!!!!->> address standardization criteria!
*
* !!!!!->> This code does NOT test for APO/FPO addresses
*
* Author, Beverly Howard 
* 
* variables used;
*    f_st      passed street1 address line
*    f_nv1     temporary numeric varible
*    bh_debug  trace and debug window trigger
* 
* 
*******************************************************
param f_st                && street address line

* if no data contained in parameter
if type("f_st") ="L"
   help postdp
   return ""
endif

if type("f_st") <> "C" .or. empty(f_st)
   ?? chr(7)
   return ""
endif

* trim and uppercase street1 line
f_st = upper(alltrim(f_st))

* find out if it is a "BOX" number
f_nv1 = at("BOX ",f_st)

do case
case len(f_st) < 5
   * no possibility of valid info
   return "99"
case f_st = "ROUTE"
   * HH rules indicate above only if NO box # entered
   * so no digits should follow
   return "99"
case f_nv1 > 0
   * it's a "BOX "... get the string that follows
   if len(f_st) > f_nv1+3
      f_st = subst(f_st,f_nv1+4)
   else
      return "99"
   endif
endcase

* should now have a number with possible imbedded alphas or "-"

* find the first <space> and delete the rest
f_nv1 = at(" ",f_st)
if f_nv1 > 0
   f_st = left(f_st,f_nv1-1)
endif

* add the leading zero now to simplify things later
f_st = "0"+f_st

* throw out the trailing alphas and get last 2 digits or
* (char/dash + digit)
f_nv1 = len(f_st)
do while f_nv1 > 1 .and. .not. isdigit(subst(f_st,f_nv1))
   f_nv1 = f_nv1 -1
enddo

do case
case f_nv1 = 1
   * nothing left but the leading "0"
   return "99"
case f_nv1 > 1 .and. isdigit(subst(f_st,f_nv1-1))
   * last 2 digits
   return subst(f_st,f_nv1-1,2)
otherwise
   * alpha + digit
   return "0"+ subst(f_st,f_nv1,1)
endcase

* and... just in case...
return "99"

* (end of function)

